@@ -51,6 +51,7 @@ either in TSV, HDF5, JSON, gzip'd JSON or gzip'd TSV and parse accordingly:
 from .table import Table
 from .parse import parse_biom_table as parse_table, load_table, save_table
 from .util import __format_version__, __version__
+from ._subsample import subsample
 
 __author__ = "Daniel McDonald"
 __copyright__ = "Copyright 2011-2020, The BIOM Format Development Team"
@@ -58,7 +59,7 @@ __credits__ = ["Daniel McDonald", "Jai Ram Rideout", "Greg Caporaso",
                "Jose Clemente", "Justin Kuczynski", "Antonio Gonzalez",
                "Yoshiki Vazquez Baeza", "Jose Navas", "Adam Robbins-Pianka",
                "Rob Knight", "Joshua Shorenstein", "Emily TerAvest",
-               "Michael Shaffer"]
+               "Michael Shaffer", "Qiyun Zhu", "Matt Aton"]
 __license__ = "BSD"
 __url__ = "http://biom-format.org"
 __maintainer__ = "Daniel McDonald"
@@ -95,4 +96,5 @@ def concat(tables, *args, **kwargs):
 
 
 __all__ = ['Table', 'example_table', 'parse_table', 'load_table',
-           '__format_version__', '__version__', 'save_table']
+           '__format_version__', '__version__', 'save_table',
+           'subsample']
